IterationPosition enum

Inheritance
Available extensions

Values

only → const IterationPosition
first → const IterationPosition
middle → const IterationPosition
last → const IterationPosition

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasNext → bool

Available on IterationPosition, provided by the IterationPositionExtensions extension

no setter
index → int
A numeric identifier for the enumerated value.
no setterinherited
isFirst → bool

Available on IterationPosition, provided by the IterationPositionExtensions extension

no setter
isLast → bool

Available on IterationPosition, provided by the IterationPositionExtensions extension

no setter
isNotFirst → bool

Available on IterationPosition, provided by the IterationPositionExtensions extension

no setter
isNotLast → bool

Available on IterationPosition, provided by the IterationPositionExtensions extension

no setter
isNotOnly → bool

Available on IterationPosition, provided by the IterationPositionExtensions extension

no setter
isOnly → bool

Available on IterationPosition, provided by the IterationPositionExtensions extension

no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<IterationPosition>
A constant List of the values in this enum, in order of their declaration.